/*
 playback

   Authors:  Giuseppe Vacanti - XMM-Newton SOC
         
   Description: Play back commands applied to a data set
 
   Comments: 
 
  $Id: playback.cc,v 1.2 2000/10/06 06:54:03 gvacanti Exp $
*/

#include "playback.h"

#include <param.h>
#include <Dal.h>
#include <errstr.h>
#include <string>
#include <Tracer.h>
#include <fstream>

static const string prefix = "# ";

static void headline(const string& s, const bool script, ostream& os){
  string ss(s.size(), '-');
  Sas::message(Msg::App, Msg::Always, prefix + ss);
  Sas::message(Msg::App, Msg::Always, prefix + s);
  Sas::message(Msg::App, Msg::Always, prefix + ss);
  if(script){
    os << prefix + ss << endl;
    os << prefix + s << endl;
    os << prefix + ss << endl;
  }
}
  

void playback ()
{
  PROC
  const bool script = booleanParameter("withscriptfile");
  ofstream os;
  if(script)
    os.open(stringParameter("scriptfile").c_str());
    
  for(int i=0; i<parameterCount("sets"); ++i){
    string name = stringParameter("sets",i);
    DataSet *set = dataSetServer->open(name, Dal::Read);
    headline("SAS commands from " + name + ":", script, os);
    for(unsigned k=0; k<dataSetServer->processes(set); ++k){
      errstr << dataSetServer->process(set,k)
	     << Sas::message(Msg::App,Msg::Always);
      if(script)
	os << dataSetServer->process(set,k) << endl;
    }

    if(booleanParameter("showdaltrace")){
      headline("SAS DAL debug trace from " + name + ":", script, os);
      for(unsigned k=0; k<dataSetServer->debugs(set); ++k){
	errstr << prefix + dataSetServer->debug(set,k)
	       << Sas::message(Msg::App,Msg::Always);
      if(script)
	os << prefix + dataSetServer->debug(set,k) << endl;
      }
    }
    
    if(booleanParameter("showhistory")){
      headline("History records from " + name + ":", script, os);      
      for(unsigned k=0; k<set->historys(); ++k){
	errstr << prefix + set->history(k)
	       << Sas::message(Msg::App,Msg::Always);
	if(script)
	  os << prefix + set->history(k) << endl;
      }
    }
  }
 ENDPROC
}
